#!/bin/bash

APPLY_PATCH=true
COMMIT_MSG=true
POST_COMMIT=true
POST_RECEIVE=true
POST_UPDATE=true
PRE_APPLY_PATCH=true
PRE_COMMIT=true
PREPARE_COMMIT_MSG=true
PRE_REBASE=true
UPDATE=true

AGGREGATOR_URL="git://git.fedorahosted.org/git/deltacloud/aggregator.git/"
CORE_URL="git://git.fedorahosted.org/git/deltacloud/core.git/"
DOCS_URL="git://git.fedorahosted.org/git/deltacloud/docs.git/"

AGGREGATOR="aggregator"
CORE="core"
DOCS="docs"

HOOKS=( $APPLY_PATCH $COMMIT_MSG $POST_COMMIT $POST_RECEIVE $POST_UPDATE $PRE_APPLY_PATCH $PRE_COMMIT $PREPARE_COMMIT_MSG $PRE_REBASE $UPDATE )
HOOK_FILES=( "applypatch-msg" "commit-msg" "post-commit" "post-receive" "post-update"  "pre-applypatch" "pre-commit" "prepare-commit-msg" "pre-rebase" "update" )

if [ $# -eq 0 ]; then
  REPOS=( $AGGREGATOR $CORE $DOCS )
  REPO_URLS=( $AGGREGATOR_URL $CORE_URL $DOCS_URL )
fi

while getopts ":acd" Option
do
  case $Option in
    a  ) REPOS[${#REPOS[*]}]=$AGGREGATOR; REPO_URLS[${#REPO_URLS[*]}]=$AGGREGATOR_URL;;
    c  ) REPOS[${#REPOS[*]}]=$CORE; REPO_URLS[${#REPO_URLS[*]}]=$CORE_URL;;
    d  ) REPOS[${#REPOS[*]}]=$DOCS; REPO_URLS[${#REPO_URLS[*]}]=$DOCS_URL;;
    *  ) echo "Invalid repository."; exit -1;;
  esac
done

WORKING_DIR=`pwd`
for (( i=0; i<${#REPOS[*]}; i++ )); do

  REPO=${REPOS[$i]}
  REPO_URL=${REPO_URLS[$i]}

  echo "Cloning Repository: " $REPO

  git clone $REPO_URL
  cd $REPO

  if [ $REPO == $AGGREGATOR ] ||  [ $REPO == $DOCS ]; then
    git checkout -t -b next origin/next
  fi
  
  # Activate each that is set to true
  HOOKS_DIR=.git/hooks

  for (( h=0; h<${#HOOKS[*]}; h++ )); do
    if [ ${HOOKS[$h]} == true ]; then
      mv $HOOKS_DIR/${HOOK_FILES[$h]}.sample $HOOKS_DIR/${HOOK_FILES[$h]}
    fi
  done
  
  cp $SCRIPTS_HOME/aggregator/.gitconfig ./.git/config
  echo $REPO

  echo "$REPO Cloned Successfully"

  cd $WORKING_DIR

done

exit 0
